'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _isFinite2 = require('lodash/isFinite');

var _isFinite3 = _interopRequireDefault(_isFinite2);

var _isEmpty2 = require('lodash/isEmpty');

var _isEmpty3 = _interopRequireDefault(_isEmpty2);

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactRouter = require('react-router');

var _reactMotion = require('react-motion');

var _styledComponents = require('styled-components');

var _styledComponents2 = _interopRequireDefault(_styledComponents);

var _d3Format = require('d3-format');

var _d3Shape = require('d3-shape');

var _theme = require('../../theme');

var _theme2 = _interopRequireDefault(_theme);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var DIAL_RADIUS_PX = 85;
var DIAL_BORDER_PX = 8;

var roundedValuePercent = function roundedValuePercent(usage) {
  // The number is really small (< 0.01%), just indicate
  // the workload isn't using much resources at all.
  if (usage < 0.01) return 0;
  // Need to show 2 decimals when 0.01% <= usage < 0.1%.
  if (usage < 0.1) return (0, _d3Format.format)('.2f')(usage);
  // Let's only show 1 decimal when 0.1% <= usage < 5%.
  if (usage < 5) return (0, _d3Format.format)('.1f')(usage);
  // Show no decimal data when 10% <= usage
  return (0, _d3Format.format)('.0f')(usage);
};

var adjustArc = function adjustArc(usage) {
  // Get rounded usage displayed inside the dial as a number [0, 1].
  var roundedUsage = Number(roundedValuePercent(usage * 100)) / 100;
  // If the displayed value is in the interval 0% < x < 1%, round up the dial arc to 1%.
  if (roundedUsage > 0 && roundedUsage < 0.01) return 0.01;
  // Otherwise, let the dial correspond to the displayed value.
  return roundedUsage;
};

var arcPath = (0, _d3Shape.arc)().innerRadius(DIAL_RADIUS_PX - DIAL_BORDER_PX).outerRadius(DIAL_RADIUS_PX).cornerRadius(5).startAngle(0).endAngle(function (percentage) {
  return 2 * Math.PI * adjustArc(percentage);
});

var DialLink = (0, _styledComponents2.default)(_reactRouter.Link).withConfig({
  displayName: 'ResourceDial__DialLink'
})(['border-radius:', ';width:', 'px;height:', 'px;display:block;'], function (props) {
  return props.theme.borderRadius.circle;
}, 2 * DIAL_RADIUS_PX, 2 * DIAL_RADIUS_PX);

var DialContainer = _styledComponents2.default.div.withConfig({
  displayName: 'ResourceDial__DialContainer'
})(['color:', ';border-radius:', ';position:relative;box-sizing:border-box;display:flex;flex-direction:column;justify-content:center;align-items:center;width:100%;height:100%;cursor:default;&:not([disabled]):hover{cursor:pointer;opacity:0.8;}'], function (props) {
  return props.theme.colors.gray600;
}, function (props) {
  return props.theme.borderRadius.circle;
});

var DialArc = _styledComponents2.default.svg.withConfig({
  displayName: 'ResourceDial__DialArc'
})(['position:absolute;pointer-events:none;left:0;top:0;']);

var DialValueContainer = _styledComponents2.default.div.withConfig({
  displayName: 'ResourceDial__DialValueContainer'
})(['display:flex;font-weight:bold;']);

var DialValue = _styledComponents2.default.div.withConfig({
  displayName: 'ResourceDial__DialValue'
})(['font-size:', ';margin:0 4px;'], function (props) {
  return props.theme.fontSizes.huge;
});

var PercentageSign = _styledComponents2.default.div.withConfig({
  displayName: 'ResourceDial__PercentageSign'
})(['font-size:', ';padding-top:6px;overflow:visible;width:0;'], function (props) {
  return props.theme.fontSizes.large;
});

var FillArc = function FillArc(_ref) {
  var color = _ref.color,
      _ref$value = _ref.value,
      value = _ref$value === undefined ? 1 : _ref$value;
  return _react2.default.createElement('path', {
    transform: 'translate(' + DIAL_RADIUS_PX + ', ' + DIAL_RADIUS_PX + ')',
    stroke: 'none',
    fill: color,
    d: arcPath(value)
  });
};

// TODO: Extract this into the theme.
var dialSpring = function dialSpring(value) {
  return (0, _reactMotion.spring)(value, { stiffness: 50, damping: 13, precision: 0.01 });
};

var ResourceDial = function (_React$PureComponent) {
  _inherits(ResourceDial, _React$PureComponent);

  function ResourceDial(props, context) {
    _classCallCheck(this, ResourceDial);

    var _this = _possibleConstructorReturn(this, (ResourceDial.__proto__ || Object.getPrototypeOf(ResourceDial)).call(this, props, context));

    _this.state = {
      value: null
    };
    return _this;
  }

  _createClass(ResourceDial, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      // eslint-disable-next-line react/no-did-mount-set-state
      this.setState({
        value: this.props.value
      });
    }
  }, {
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      // setState is async so triggers another render allowing animation to happen
      this.setState({
        value: nextProps.value
      });
    }
  }, {
    key: 'render',
    value: function render() {
      var value = this.state.value;
      var _props = this.props,
          label = _props.label,
          disabled = _props.disabled,
          to = _props.to;

      var hasLink = !(0, _isEmpty3.default)(to) && !disabled;
      var hasValue = (0, _isFinite3.default)(value);

      return _react2.default.createElement(
        DialLink,
        { to: hasLink ? to : '' },
        _react2.default.createElement(
          _reactMotion.Motion,
          { style: { interpolatedValue: dialSpring(hasValue ? value : 0) } },
          function (_ref2) {
            var interpolatedValue = _ref2.interpolatedValue;
            return _react2.default.createElement(
              DialContainer,
              { disabled: !hasLink },
              _react2.default.createElement(
                DialValueContainer,
                null,
                _react2.default.createElement(
                  DialValue,
                  null,
                  hasValue ? roundedValuePercent(interpolatedValue * 100) : '-'
                ),
                hasValue && _react2.default.createElement(
                  PercentageSign,
                  null,
                  '%'
                )
              ),
              label,
              _react2.default.createElement(
                DialArc,
                { width: '100%', height: '100%' },
                _react2.default.createElement(FillArc, { color: _theme2.default.colors.gray100 }),
                _react2.default.createElement(FillArc, {
                  color: _theme2.default.colors.blue600,
                  value: interpolatedValue
                })
              )
            );
          }
        )
      );
    }
  }]);

  return ResourceDial;
}(_react2.default.PureComponent);

ResourceDial.propTypes = {
  /**
   * Resource usage label shown below the percentage value
   */
  label: _propTypes2.default.string.isRequired,
  /**
   * The percentage value to be displayed by the dial, should be between 0 and 1
   */
  value: _propTypes2.default.number,
  /**
   * Disables the link if set to true
   */
  disabled: _propTypes2.default.bool,
  /**
   * React router link for clicking on the dial
   */
  to: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.object])
};

ResourceDial.defaultProps = {
  value: null,
  disabled: false,
  to: ''
};

exports.default = ResourceDial;